import { reactive, computed, watch } from 'vue'
import useForm from '@/hooks/useForm'
import useOptions from '@/hooks/useOptions'
import useVW from '@/hooks/useVW'

import type { EpFormItem } from 'global-type'
import type { ExtractApiParams } from '@/api/api'

const useFormFilter = () => {
  const {
    subjectList,
    mainQuestionList,
    groupListWithAll,
    changeModelValue,
    dataModel,
    onOptionInit,
    isExpert,
    isLeader,
  } = useOptions(['subject', 'question', 'group'])
  const { formRef, elFormRef, defineColumn, _ } = useForm()

  const model = reactive<
    Omit<ExtractApiParams<'getGroupMonitor'>, 'markingGroupNumber'> & { markingGroupNumber?: number | string }
  >({
    subjectCode: dataModel.subject || '',
    markingGroupNumber: dataModel.group,
    questionMainNumber: dataModel.question,
  })

  const formModel = computed<any>(() => {
    return {
      subjectCode: model.subjectCode,
      // markingGroupNumber:
      //   typeof model.markingGroupNumber === 'number' ? [model.markingGroupNumber] : model.markingGroupNumber,
      markingGroupNumber: model.markingGroupNumber,
      questionMainNumber: model.questionMainNumber,
    }
  })

  watch(dataModel, () => {
    model.subjectCode = dataModel.subject || ''
    model.questionMainNumber = dataModel.question
    model.markingGroupNumber = dataModel.group
  })

  const OneRowSpan5 = defineColumn(_, 'row-1', { span: 5 })

  const items = computed<EpFormItem[]>(() => [
    OneRowSpan5({
      label: '科目',
      prop: 'subjectCode',
      slotType: 'select',
      slot: {
        disabled: !isExpert.value,
        options: subjectList.value,
        onChange: changeModelValue('subject'),
      },
    }),
    OneRowSpan5({
      prop: 'questionMainNumber',
      label: '大题',
      slotType: 'select',
      slot: {
        disabled: !isExpert.value && !isLeader.value,
        options: mainQuestionList.value,
        onChange: changeModelValue('question'),
      },
    }),
    OneRowSpan5({
      prop: 'markingGroupNumber',
      label: '小组',
      slotType: 'select',
      slot: {
        options: groupListWithAll.value,
        onChange: changeModelValue('group'),
      },
    }),
    OneRowSpan5({
      labelWidth: '20px',
      slotName: 'button-group',
    }),
  ])

  return {
    formRef,
    elFormRef,
    model,
    formModel,
    items,
    onOptionInit,
  }
}

export default useFormFilter
